OC.L10N.register(
    "password_policy",
    {
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Parool kuulub 1000000 kõige tavalisema hulka. Palun tee see ainulaadseks.",
    "Password needs to contain at least one numeric character." : "Parool peab sisaldama vähemalt üht numbrit",
    "Password needs to contain at least one special character." : "Parool peab sisaldama vähemalt üht erimärki.",
    "Password needs to contain at least one lower and one upper case character." : "Parool peab sisaldama vähemalt üht väike- ja suurtähte",
    "Password policy" : "Paroolipoliitika",
    "Forbid common passwords" : "Keela üldlevinud paroolid",
    "Enforce upper and lower case characters" : "Sunni suured ja väikesed tähed",
    "Enforce numeric characters" : "Sunni numbrilised sümbolid",
    "Enforce special characters" : "Sunni erimärgid",
    "Unknown error" : "Tundmatu viga",
    "Settings saved" : "Seaded salvestatud",
    "Saved" : "Salvestatud"
},
"nplurals=2; plural=(n != 1);");
